module Ruby
  module Terraform
    module Commands
      class ApplyCommand
        include ExecutionSupport

        attr_accessor :dir
        attr_accessor :state
        attr_accessor :vars
        attr_accessor :auto_approve

        def initialize(opts = {})
          @dir = opts[:dir]
          @state = opts[:state]
          @vars = opts[:vars]
          @auto_approve = if opts[:auto_approve].nil?
                            true
                          else
                            opts[:auto_approve]
                          end
        end

        def command
          cmd = %W[#{tf_binary} apply]

          cmd += ['-state', state] if state
          cmd += ['-auto-approve'] if auto_approve

          if vars
            vars.each do |key, value|
              var_value = value.is_a?(String) ? value : JSON.generate(value)
              cmd += ['-var', "#{key}=#{var_value}"]
            end
          end

          cmd += [dir] if dir
          cmd
        end
      end
    end
  end
end
